[![wq.db][logo]][docs]

[**wq.db**][docs] is a collection of Python modules for building robust, flexible schemas and REST APIs for use in creating field data collection apps and (more generally) mobile-first websites with progressive enhancement.  wq.db is the backend component of [wq] and is geared primarily for use with [wq.app], though it can be used separately.  wq.db is built on the [Django] platform.

[![Latest PyPI Release](https://img.shields.io/pypi/v/wq.db.svg)](https://pypi.org/project/wq.db)
[![Release Notes](https://img.shields.io/github/release/wq/wq.db.svg)](https://github.com/wq/wq.db/releases)
[![Documentation](https://img.shields.io/badge/Docs-1.3-blue.svg)][docs]
[![License](https://img.shields.io/pypi/l/wq.db.svg)](https://wq.io/license)
[![GitHub Stars](https://img.shields.io/github/stars/wq/wq.db.svg)](https://github.com/wq/wq.db/stargazers)
[![GitHub Forks](https://img.shields.io/github/forks/wq/wq.db.svg)](https://github.com/wq/wq.db/network)
[![GitHub Issues](https://img.shields.io/github/issues/wq/wq.db.svg)](https://github.com/wq/wq.db/issues)

[![Tests](https://github.com/wq/wq.db/actions/workflows/test.yml/badge.svg)](https://github.com/wq/wq.db/actions/workflows/test.yml)
[![Python Support](https://img.shields.io/pypi/pyversions/wq.db.svg)](https://pypi.org/project/wq.db)
[![Django Support](https://img.shields.io/pypi/djversions/wq.db.svg)](https://pypi.org/project/wq.db)

### [Documentation][docs]

[**Installation**][installation]

[**API**][api]
<br>
[wq Config Object][config]
&bull;
[URL Structure][url-structure]
&bull;
[Settings][settings]

[**wq.db.rest**][rest]
<br>
[ModelRouter][router]
&bull;
[ModelSerializer][serializers]
&bull;
[ModelViewSet][views]

[**wq.db.patterns**][patterns]
<br>
[Repeating Nested Forms][nested-forms]

[logo]: https://wq.io/images/wq.db.svg
[docs]: https://wq.io/wq.db/

[installation]: https://wq.io/wq.db/#installation
[api]: https://wq.io/wq.db/#api
[config]: https://wq.io/config
[url-structure]: https://wq.io/wq.db/url-structure
[settings]: https://wq.io/wq.db/settings
[rest]: https://wq.io/wq.db/rest
[router]: https://wq.io/wq.db/router
[serializers]: https://wq.io/wq.db/serializers
[views]: https://wq.io/wq.db/views
[patterns]: https://wq.io/wq.db/patterns
[nested-forms]: https://wq.io/guides/implement-repeating-nested-forms

[wq]: https://wq.io
[wq.app]: https://wq.io/wq.app/
[Django]: https://www.djangoproject.com/
